@@ -14,21 +14,22 @@ Usage::
 """
 from typing import IO, Any, Dict, List, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
+from botocore.response import StreamingBody
 
 from .literals import GrowthTypeType, ReplicateToType
 from .type_defs import (
+    ApplicationResponseMetadataTypeDef,
     ApplicationsTypeDef,
-    ApplicationTypeDef,
     ConfigurationProfilesTypeDef,
     ConfigurationProfileTypeDef,
     ConfigurationTypeDef,
     DeploymentStrategiesTypeDef,
-    DeploymentStrategyTypeDef,
+    DeploymentStrategyResponseMetadataTypeDef,
     DeploymentsTypeDef,
     DeploymentTypeDef,
+    EnvironmentResponseMetadataTypeDef,
     EnvironmentsTypeDef,
-    EnvironmentTypeDef,
     HostedConfigurationVersionsTypeDef,
     HostedConfigurationVersionTypeDef,
     MonitorTypeDef,
@@ -57,26 +58,36 @@ class Exceptions:
     ServiceQuotaExceededException: Type[BotocoreClientError]
 
 
-class AppConfigClient:
+class AppConfigClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        AppConfigClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#can_paginate)
         """
 
     def create_application(
         self, *, Name: str, Description: str = None, Tags: Dict[str, str] = None
-    ) -> "ApplicationTypeDef":
+    ) -> ApplicationResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.create_application)
+        An application in AppConfig is a logical unit of code that provides capabilities
+        for your customers.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.create_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_application)
         """
 
@@ -92,7 +103,9 @@ class AppConfigClient:
         Tags: Dict[str, str] = None
     ) -> ConfigurationProfileTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.create_configuration_profile)
+        Information that enables AppConfig to access the configuration source.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.create_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_configuration_profile)
         """
 
@@ -107,9 +120,12 @@ class AppConfigClient:
         FinalBakeTimeInMinutes: int = None,
         GrowthType: GrowthTypeType = None,
         Tags: Dict[str, str] = None
-    ) -> "DeploymentStrategyTypeDef":
+    ) -> DeploymentStrategyResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.create_deployment_strategy)
+        A deployment strategy defines important criteria for rolling out your
+        configuration to the designated targets.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.create_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_deployment_strategy)
         """
 
@@ -121,9 +137,11 @@ class AppConfigClient:
         Description: str = None,
         Monitors: List["MonitorTypeDef"] = None,
         Tags: Dict[str, str] = None
-    ) -> "EnvironmentTypeDef":
+    ) -> EnvironmentResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.create_environment)
+        For each application, you define one or more environments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.create_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_environment)
         """
 
@@ -132,19 +150,23 @@ class AppConfigClient:
         *,
         ApplicationId: str,
         ConfigurationProfileId: str,
-        Content: Union[bytes, IO[bytes]],
+        Content: Union[bytes, IO[bytes], StreamingBody],
         ContentType: str,
         Description: str = None,
         LatestVersionNumber: int = None
     ) -> HostedConfigurationVersionTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.create_hosted_configuration_version)
+        Create a new configuration in the AppConfig configuration store.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.create_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_hosted_configuration_version)
         """
 
     def delete_application(self, *, ApplicationId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.delete_application)
+        Delete an application.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.delete_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_application)
         """
 
@@ -152,19 +174,25 @@ class AppConfigClient:
         self, *, ApplicationId: str, ConfigurationProfileId: str
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.delete_configuration_profile)
+        Delete a configuration profile.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.delete_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_configuration_profile)
         """
 
     def delete_deployment_strategy(self, *, DeploymentStrategyId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.delete_deployment_strategy)
+        Delete a deployment strategy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.delete_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_deployment_strategy)
         """
 
     def delete_environment(self, *, ApplicationId: str, EnvironmentId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.delete_environment)
+        Delete an environment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.delete_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_environment)
         """
 
@@ -172,7 +200,9 @@ class AppConfigClient:
         self, *, ApplicationId: str, ConfigurationProfileId: str, VersionNumber: int
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.delete_hosted_configuration_version)
+        Delete a version of a configuration from the AppConfig configuration store.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.delete_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_hosted_configuration_version)
         """
 
@@ -184,13 +214,17 @@ class AppConfigClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#generate_presigned_url)
         """
 
-    def get_application(self, *, ApplicationId: str) -> "ApplicationTypeDef":
+    def get_application(self, *, ApplicationId: str) -> ApplicationResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.get_application)
+        Retrieve information about an application.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.get_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_application)
         """
 
@@ -204,7 +238,9 @@ class AppConfigClient:
         ClientConfigurationVersion: str = None
     ) -> ConfigurationTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.get_configuration)
+        Receive information about a configuration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.get_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_configuration)
         """
 
@@ -212,7 +248,9 @@ class AppConfigClient:
         self, *, ApplicationId: str, ConfigurationProfileId: str
     ) -> ConfigurationProfileTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.get_configuration_profile)
+        Retrieve information about a configuration profile.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.get_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_configuration_profile)
         """
 
@@ -220,19 +258,29 @@ class AppConfigClient:
         self, *, ApplicationId: str, EnvironmentId: str, DeploymentNumber: int
     ) -> DeploymentTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.get_deployment)
+        Retrieve information about a configuration deployment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.get_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_deployment)
         """
 
-    def get_deployment_strategy(self, *, DeploymentStrategyId: str) -> "DeploymentStrategyTypeDef":
+    def get_deployment_strategy(
+        self, *, DeploymentStrategyId: str
+    ) -> DeploymentStrategyResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.get_deployment_strategy)
+        Retrieve information about a deployment strategy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.get_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_deployment_strategy)
         """
 
-    def get_environment(self, *, ApplicationId: str, EnvironmentId: str) -> "EnvironmentTypeDef":
+    def get_environment(
+        self, *, ApplicationId: str, EnvironmentId: str
+    ) -> EnvironmentResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.get_environment)
+        Retrieve information about an environment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.get_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_environment)
         """
 
@@ -240,7 +288,9 @@ class AppConfigClient:
         self, *, ApplicationId: str, ConfigurationProfileId: str, VersionNumber: int
     ) -> HostedConfigurationVersionTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.get_hosted_configuration_version)
+        Get information about a specific configuration version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.get_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_hosted_configuration_version)
         """
 
@@ -248,7 +298,9 @@ class AppConfigClient:
         self, *, MaxResults: int = None, NextToken: str = None
     ) -> ApplicationsTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.list_applications)
+        List all applications in your AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.list_applications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_applications)
         """
 
@@ -256,7 +308,9 @@ class AppConfigClient:
         self, *, ApplicationId: str, MaxResults: int = None, NextToken: str = None
     ) -> ConfigurationProfilesTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.list_configuration_profiles)
+        Lists the configuration profiles for an application.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.list_configuration_profiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_configuration_profiles)
         """
 
@@ -264,7 +318,9 @@ class AppConfigClient:
         self, *, MaxResults: int = None, NextToken: str = None
     ) -> DeploymentStrategiesTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.list_deployment_strategies)
+        List deployment strategies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.list_deployment_strategies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_deployment_strategies)
         """
 
@@ -277,7 +333,9 @@ class AppConfigClient:
         NextToken: str = None
     ) -> DeploymentsTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.list_deployments)
+        Lists the deployments for an environment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.list_deployments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_deployments)
         """
 
@@ -285,7 +343,9 @@ class AppConfigClient:
         self, *, ApplicationId: str, MaxResults: int = None, NextToken: str = None
     ) -> EnvironmentsTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.list_environments)
+        List the environments for an application.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.list_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_environments)
         """
 
@@ -298,13 +358,18 @@ class AppConfigClient:
         NextToken: str = None
     ) -> HostedConfigurationVersionsTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.list_hosted_configuration_versions)
+        View a list of configurations stored in the AppConfig configuration store by
+        version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.list_hosted_configuration_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_hosted_configuration_versions)
         """
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ResourceTagsTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.list_tags_for_resource)
+        Retrieves the list of key-value tags assigned to the resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_tags_for_resource)
         """
 
@@ -320,7 +385,9 @@ class AppConfigClient:
         Tags: Dict[str, str] = None
     ) -> DeploymentTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.start_deployment)
+        Starts a deployment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.start_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#start_deployment)
         """
 
@@ -328,27 +395,35 @@ class AppConfigClient:
         self, *, ApplicationId: str, EnvironmentId: str, DeploymentNumber: int
     ) -> DeploymentTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.stop_deployment)
+        Stops a deployment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.stop_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#stop_deployment)
         """
 
     def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.tag_resource)
+        Metadata to assign to an AppConfig resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.untag_resource)
+        Deletes a tag key and value from an AppConfig resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#untag_resource)
         """
 
     def update_application(
         self, *, ApplicationId: str, Name: str = None, Description: str = None
-    ) -> "ApplicationTypeDef":
+    ) -> ApplicationResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.update_application)
+        Updates an application.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.update_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_application)
         """
 
@@ -363,7 +438,9 @@ class AppConfigClient:
         Validators: List["ValidatorTypeDef"] = None
     ) -> ConfigurationProfileTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.update_configuration_profile)
+        Updates a configuration profile.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.update_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_configuration_profile)
         """
 
@@ -376,9 +453,11 @@ class AppConfigClient:
         FinalBakeTimeInMinutes: int = None,
         GrowthFactor: float = None,
         GrowthType: GrowthTypeType = None
-    ) -> "DeploymentStrategyTypeDef":
+    ) -> DeploymentStrategyResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.update_deployment_strategy)
+        Updates a deployment strategy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.update_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_deployment_strategy)
         """
 
@@ -390,9 +469,11 @@ class AppConfigClient:
         Name: str = None,
         Description: str = None,
         Monitors: List["MonitorTypeDef"] = None
-    ) -> "EnvironmentTypeDef":
+    ) -> EnvironmentResponseMetadataTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.update_environment)
+        Updates an environment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.update_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_environment)
         """
 
@@ -400,6 +481,8 @@ class AppConfigClient:
         self, *, ApplicationId: str, ConfigurationProfileId: str, ConfigurationVersion: str
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig.Client.validate_configuration)
+        Uses the validators in a configuration profile to validate a configuration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/appconfig.html#AppConfig.Client.validate_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#validate_configuration)
         """
